@@ -437,7 +437,7 @@ public:
 			out(h.h.first).writeChars(buf, ss.tellp());
 		}
 		unlock(hs[end-1].h.first);
-                tthread::lock_guard<MUTEX_T> guard(main_mutex_m);
+		GUARD_LOCK(main_mutex_m);
 		commitHits(hs);
 		first_ = false;
 		numAligned_++;
@@ -609,7 +609,7 @@ public:
 		if(!p.paired() || onePairFile_) {
 			// Dump unpaired read to an aligned-read file of the same format
 			if(!dumpAlBase_.empty()) {
-				tthread::lock_guard<MUTEX_T> guard(dumpAlignLock_);
+				GUARD_LOCK(dumpAlignLock_);
 				if(dumpAl_ == NULL) {
 					assert(dumpAlQv_ == NULL);
 					dumpAl_ = openOf(dumpAlBase_, 0, "");
@@ -628,7 +628,7 @@ public:
 			// Dump paired-end read to an aligned-read file (or pair of
 			// files) of the same format
 			if(!dumpAlBase_.empty()) {
-				tthread::lock_guard<MUTEX_T> guard(dumpAlignLockPE_);
+				GUARD_LOCK(dumpAlignLockPE_);
 				if(dumpAl_1_ == NULL) {
 					assert(dumpAlQv_1_ == NULL);
 					assert(dumpAlQv_2_ == NULL);
@@ -663,7 +663,7 @@ public:
 		if(!p.paired() || onePairFile_) {
 			// Dump unpaired read to an unaligned-read file of the same format
 			if(!dumpUnalBase_.empty()) {
-				tthread::lock_guard<MUTEX_T> guard(dumpUnalLock_);
+				GUARD_LOCK(dumpUnalLock_);
 				if(dumpUnal_ == NULL) {
 					assert(dumpUnalQv_ == NULL);
 					dumpUnal_ = openOf(dumpUnalBase_, 0, "");
@@ -682,7 +682,7 @@ public:
 			// Dump paired-end read to an unaligned-read file (or pair
 			// of files) of the same format
 			if(!dumpUnalBase_.empty()) {
-				tthread::lock_guard<MUTEX_T> guard(dumpUnalLockPE_);
+				GUARD_LOCK(dumpUnalLockPE_);
 				if(dumpUnal_1_ == NULL) {
 					assert(dumpUnal_1_ == NULL);
 					assert(dumpUnal_2_ == NULL);
@@ -718,7 +718,7 @@ public:
 		if(!p.paired() || onePairFile_) {
 			// Dump unpaired read to an maxed-out-read file of the same format
 			if(!dumpMaxBase_.empty()) {
-				tthread::lock_guard<MUTEX_T> guard(dumpMaxLock_);
+				GUARD_LOCK(dumpMaxLock_);
 				if(dumpMax_ == NULL) {
 					dumpMax_ = openOf(dumpMaxBase_, 0, "");
 					assert(dumpMax_ != NULL);
@@ -735,7 +735,7 @@ public:
 			// Dump paired-end read to a maxed-out-read file (or pair
 			// of files) of the same format
 			if(!dumpMaxBase_.empty()) {
-				tthread::lock_guard<MUTEX_T> guard(dumpMaxLockPE_);
+				GUARD_LOCK(dumpMaxLockPE_);
 				if(dumpMax_1_ == NULL) {
 					assert(dumpMaxQv_1_ == NULL);
 					assert(dumpMaxQv_2_ == NULL);
@@ -763,7 +763,7 @@ public:
 	 * want to print a placeholder when output is chained.
 	 */
 	virtual void reportMaxed(vector<Hit>& hs, PatternSourcePerThread& p) {
-		tthread::lock_guard<MUTEX_T> guard(main_mutex_m);
+		GUARD_LOCK(main_mutex_m);
 		numMaxed_++;
 	}
 
@@ -772,7 +772,7 @@ public:
 	 * want to print a placeholder when output is chained.
 	 */
 	virtual void reportUnaligned(PatternSourcePerThread& p) {
-		tthread::lock_guard<MUTEX_T> guard(main_mutex_m);
+		GUARD_LOCK(main_mutex_m);
 		numUnaligned_++;
 	}
 
@@ -781,7 +781,7 @@ protected:
 	/// Implementation of hit-report
 	virtual void reportHit(const Hit& h) {
 		assert(h.repOk());
-		tthread::lock_guard<MUTEX_T> guard(main_mutex_m);
+		GUARD_LOCK(main_mutex_m);
 		commitHit(h);
 		first_ = false;
 		if(h.mate > 0) numReportedPaired_++;
